@@ -25,7 +25,7 @@
 #
 # HUBzero is a registered trademark of The Regents of the University of California.
 #
-__version__ = '3.9.1'
+__version__ = '3.10.1'
 
 import sys
 import os
@@ -91,14 +91,18 @@ class JobHarvester:
    def __init__(self,
                 configurationDirectory,
                 distributorConfigurationFile,
+                daemonsDirectory,
                 daemonsConfigurationFile,
+                infosDirectory,
                 infosConfigurationFile):
       self.logger = logging.getLogger(__name__)
 
       self.configData = {}
       self.configurationDirectory       = configurationDirectory
       self.distributorConfigurationFile = distributorConfigurationFile
+      self.daemonsDirectory             = daemonsDirectory
       self.daemonsConfigurationFile     = daemonsConfigurationFile
+      self.infosDirectory               = infosDirectory
       self.infosConfigurationFile       = infosConfigurationFile
 
       self.version              = __version__
@@ -113,7 +117,7 @@ class JobHarvester:
       self.dataDirectory        = ''
       self.binDirectory         = ''
 
-      configFilePath = os.path.join(self.configurationDirectory,self.daemonsConfigurationFile)
+      configFilePath = os.path.join(self.daemonsDirectory,self.daemonsConfigurationFile)
       self.daemonsInfo       = DaemonsInfo(configFilePath)
       self.identityListenURI = self.daemonsInfo.getDaemonListenURI('identitiesManager','tcp')
       self.tunnelListenURI   = self.daemonsInfo.getDaemonListenURI('tunnelMonitor','tcp')
@@ -349,7 +353,7 @@ class JobHarvester:
 
 
    def setInfo(self):
-      configFilePath = os.path.join(self.configurationDirectory,self.infosConfigurationFile)
+      configFilePath = os.path.join(self.infosDirectory,self.infosConfigurationFile)
       self.infosInfo = InfosInfo(configFilePath)
 
       self.sitesInfo = SitesInfo(self.infosInfo.getInfoPath('sites'),
